
NO_LAG, SECONDS_IN_DAY = 1, 86400
KEY_VALS = ("open", "high", "low", "close", "volume")

NO_PERIOD_INDS = ['HT_TRENDLINE', 'BOP', 'SAR', 'OBV']
SINGLE_PERIOD_INDS = ['MA', 'RSI', 'BBANDS','MIDPOINT','MIDPRICE','ADX','ADXR','AROON','AROONOSC','CCI','CMO','MACDFIX','MFI','MINUS_DI','MINUS_DM','MOM', 'WILLR', 'TEMA', 'ATR', 'ROCR', 'TRIX']
TWO_PERIOD_INDS = ['MACD', 'PPO', 'APO']
